*------------------------------ BASELINE TREATMENTS (APPENDIX A) ---------------------
clear
use "u:\data\supplemental\baseline.dat"
*-- TABLE A1 - The effects of communication
tabulate roll treat, column
tabstat sob if treat==0, stat(mean sd)
tabstat sob if treat==1, stat(mean sd)

* TESTS (first round choices are independent)
* Test of proportions for roll rate
prtest roll if t==1, by(treat)
* Ranksum test for second order beliefs
ranksum sob if t==1, by(treat)

*------------------------------ SWITCHING TREATMENT (SECTION 4) ---------------------

*-- TABLE I: The effects of partner switching
use "U:\DATA\supplemental\switch.dat",replace
tabstat sob if type==1, by (switch) stat(mean, sd)
tabulate roll switch if type==1, column
*Note: the sd for frequency is estimated from sqrt( (phat)(1-phat)/n )

*------SIGNED RANK TESTS: Each session is one pair of observations-----
* SWITCHING AND BEHAVIOR: 
* Compare average roll rates under switch / no switch condition
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type == 0
gen s_roll = roll if switch==1
gen ns_roll = roll if switch==0
collapse (mean) s_roll ns_roll, by (session)
signrank s_roll = ns_roll

* SWITCHING AND BELIEFS: 
* Compare average SOB under switch / no switch condition
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type == 0
gen sob_switch = sob if switch==1
gen sob_noswitch = sob if switch==0
collapse (mean) sob_switch sob_noswitch, by (session)
signrank sob_switch = sob_noswitch 

*-- TABLE II: Promises and second order beliefs
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type==0
tabstat sob if promise == 1 & switch == 0, stats(mean sd)
tabstat sob if promise == 0 & switch == 0, stats(mean sd)
tabstat sob if promise == 1 & switch == 1 & pr_promise == 1, stats(mean sd)
tabstat sob if promise == 0 & switch == 1 & pr_promise == 1, stats(mean sd)
tabstat sob if promise == 1 & switch == 1 & pr_promise == 0, stats(mean sd)
tabstat sob if promise == 0 & switch == 1 & pr_promise == 0, stats(mean sd)

*--TABLE III: Promises and behavior
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type==0
tabulate roll promise if type == 1 & switch == 0, column
tabulate roll promise if type == 1 & switch == 1 & pr_promise == 1, column
tabulate roll promise if type == 1 & switch == 1 & pr_promise == 0, column

* Signed Rank tests - Roll rates
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type==0
gen P_NS_ROLL = roll if promise*(1-switch) == 1
gen NP_NS_ROLL = roll if (1-promise)*(1-switch) == 1
gen P_PR_ROLL = roll if switch*promise*pr_promise == 1
gen NP_PR_ROLL = roll if switch*(1-promise)*pr_promise == 1
gen P_NPR_ROLL = roll if switch*promise*(1-pr_promise) == 1
gen NP_NPR_ROLL = roll if switch*(1-promise)*(1-pr_promise) == 1
collapse (mean) P_* NP_*, by(session)

* Results reported in text
signrank P_NS = NP_NS
signrank P_NS = P_PR
* footnote 11
signrank P_PR = NP_PR
signrank P_NPR = NP_NPR
*footnote 13
signrank P_PR = P_NPR
signrank NP_PR = NP_NPR

*-- Signed rank tests - Second-order beliefs
clear
use "U:\DATA\supplemental\switch.dat",replace
drop if type==0
gen P_NS_SOB = sob if promise*(1-switch) == 1
gen NP_NS_SOB = sob if (1-promise)*(1-switch) == 1
gen P_PR_SOB = sob if switch*promise*pr_promise == 1
gen NP_PR_SOB = sob if switch*(1-promise)*pr_promise == 1
gen P_NPR_SOB = sob if switch*promise*(1-pr_promise) == 1
gen NP_NPR_SOB = sob if switch*(1-promise)*(1-pr_promise) == 1
collapse (mean) P_* NP_*, by(session)

*Results reported in text
signrank P_NS = NP_NS
signrank P_NS = P_PR

*footnote 12
signrank P_PR = P_NPR
signrank NP_PR = NP_NPR_S

* --------------------------------------- REGRESSIONS (Table A.II) -------------------------------------------
clear
use "U:\DATA\supplemental\switch.dat",replace
xtset subject t
drop if type==0

gen noswitch = 1-switch
gen sobXswitch = sob*switch
gen sobXnoswitch = sob*(1-switch)
gen promiseXswitch = promise*switch
gen promiseXnoswitch = promise*noswitch 
gen sobXpromise = promise*sob
gen sobXpromiseXswitch = sob*promise*switch
gen sobXpromiseXswitchXpr_promise = sob*promise*switch*pr_promise
gen switchXpr_promise = switch*pr_promise
gen sobXswitchXpr_promise = switchXpr_promise*sob
gen promiseXswitchXpr_promise = promise*switch*pr_promise 
gen sobXpromiseXnoswitch = sob*promiseXnoswitch
gen nopromise = 1-promise
gen sobXnopromise = sob*nopromise

*-The following code generates a tab delimited file corresponding to table A.II

#delimit;
gllamm roll promise switch sob promiseXswitch sobXpromise 
	switchXpr_promise sobXswitch 
	promiseXswitchXpr_promise sobXswitchXpr_promise sobXpromiseXswitch
	t
	, i(subject) l(logit) f(binom) robust cluster(session);
est store RILOG1;
#delimit cr
#delimit;
gllamm roll promise switch sob promiseXswitch sobXpromise 
	switchXpr_promise sobXswitch
	t
	, i(subject) l(logit) f(binom) robust cluster(session);
est store RILOG2;
#delimit cr
#delimit;
gllamm roll promise switch sob promiseXswitch sobXpromise t
	, i(subject) l(logit) f(binom) robust cluster(session);
est store RILOG3;
#delimit cr
#delimit;
gllamm roll promise switch sob promiseXswitch t
	, i(subject) l(logit) f(binom) robust cluster(session);
est store RILOG4;
#delimit cr

gllamm roll promise switch sob promiseXswitch t, i(subject) l(probit) f(binom) robust cluster(session)
est store PROBIT
clogit roll promise switch sob promiseXswitch t, group(subject)
est store CONDLOGIT
xtreg roll promise switch sob promiseXswitch t, i(subject) cluster(session)
est store LINEAR

estout RILOG1 RILOG2 RILOG3 RILOG4 PROBIT CONDLOGIT LINEAR using "U:\DATA\supplemental\regtable.txt", replace starlevels(* 0.1 ** 0.05 *** 0.01) stats(ll,  labels("Log Likelihood")) cells(b(fmt(2) star) se(par)) varwidth(30) modelwidth(10) label varlabels(_cons Constant) style(tab)
